==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/readGenes.R <==
genotypeFileFormats <- c("ped","pfizer","hapmap.ped","fbat.ped","pbat.ped","perlegen")
phenotypeFileFormats <- c("csv","table","fwf","fbat.phe","pbat.phe")
markerFileFormats <- c("csv","table","fwf")

readGenes <- function(gfile, gformat=genotypeFileFormats,
                      goptions=list(),
                      pfile, pformat=phenotypeFileFormats,
                      poptions=list(),
                      mfile, mformat=markerFileFormats,
                      moptions=list()
                      )
                                
{
  if(is.character(gfile) && !file.exists(gfile))
    stop('Genotype file ', gfile, ' does not exist')

  if(!missing(pfile) && is.character(pfile) && !file.exists(pfile))
    stop('Phenotype file ', pfile, ' does not exist')

  if(!missing(mfile) && is.character(mfile) && !file.exists(mfile))
    stop('Marker file ', mfile, ' does not exist')
  
  if(is.function(gformat))
    gformat <- deparse(substitute(gformat))
  else
    gformat <- paste("readGenes",match.arg(gformat),sep=".")

  if(is.function(pformat))
    pformat <- deparse(substitute(pformat))
  else
    pformat <- paste("read",match.arg(pformat),sep=".")

  if(is.function(mformat))
    mformat <- deparse(substitute(mformat))
  else
    mformat <- paste("read",match.arg(mformat),sep=".")

  
  ## step 1: load the genotype data
  goptions$filename <- gfile
  gobj <- do.call(gformat, goptions)
  if(!("geneSet" %in% class(gobj)))
    stop("Call to function ", fname,
         " failed to return an object of class `geneSet'.")

  ## (optional) step 2: load the phenotype data
  if(!missing(pfile) && !is.null(pfile))
    {
      poptions$file <- pfile
      pobj <- do.call(pformat, poptions)
      if(!("data.frame" %in% class(pobj)))
        stop("Call to function ", pformat,
             " failed to return an object of class `data.frame'.")

      if( any(colnames(pobj) %in% colnames(sampleInfo(gobj))) )
         sampleInfo(gobj) <- merge(sampleInfo(gobj), pobj, all.x=TRUE)
      else
         sampleInfo(gobj) <- cbind(sampleInfo(gobj), pobj)
    }

  ## (optional) step 3: load the marker data
  if(!missing(mfile) && !is.null(mfile))
    {
      moptions$file <- mfile
      mobj <- do.call(mformat, moptions)
      if(!("data.frame" %in% class(mobj)))
        stop("Call to function ", mformat,
             " failed to return an object of class `data.frame'.")

      if( is.null(markerInfo(gobj)) )
         markerInfo(gobj) <- mobj
      else if( any(colnames(mobj) %in% colnames(markerInfo(gobj))) )
         markerInfo(gobj) <- merge(markerInfo(gobj), mobj, all.x=TRUE)
      else if(nrow(markerInfo(gobj))==nrow(mobj))
         markerInfo(gobj) <- cbind(markerInfo(gobj), mobj)
      else
        warning("Marker file info does not match dimensions or marker names from genotype file. Ignoring")
    }
  

  gobj
}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/readGenes.R <==
genotypeFileFormats <- c("ped","pfizer","hapmap.ped","fbat.ped","pbat.ped","perlegen")
phenotypeFileFormats <- c("csv","table","fwf","fbat.phe","pbat.phe")
markerFileFormats <- c("csv","table","fwf")

readGenes <- function(gfile, gformat=genotypeFileFormats,
                      goptions=list(),
                      pfile, pformat=phenotypeFileFormats,
                      poptions=list(),
                      mfile, mformat=markerFileFormats,
                      moptions=list()
                      )
                                
{
  if(is.character(gfile) && !file.exists(gfile))
    stop('Genotype file ', gfile, ' does not exist')

  if(!missing(pfile) && is.character(pfile) && !file.exists(pfile))
    stop('Phenotype file ', pfile, ' does not exist')

  if(!missing(mfile) && is.character(mfile) && !file.exists(mfile))
    stop('Marker file ', mfile, ' does not exist')
  
  if(is.function(gformat))
    gformat <- deparse(substitute(gformat))
  else
    gformat <- paste("readGenes",match.arg(gformat),sep=".")

  if(is.function(pformat))
    pformat <- deparse(substitute(pformat))
  else
    pformat <- paste("read",match.arg(pformat),sep=".")

  if(is.function(mformat))
    mformat <- deparse(substitute(mformat))
  else
    mformat <- paste("read",match.arg(mformat),sep=".")

  
  ## step 1: load the genotype data
  goptions$filename <- gfile
  gobj <- do.call(gformat, goptions)
  if(!("geneSet" %in% class(gobj)))
    stop("Call to function ", gformat,
         " failed to return an object of class `geneSet'.")

  ## (optional) step 2: load the phenotype data
  if(!missing(pfile) && !is.null(pfile))
    {
      poptions$file <- pfile
      pobj <- do.call(pformat, poptions)
      if(!("data.frame" %in% class(pobj)))
        stop("Call to function ", pformat,
             " failed to return an object of class `data.frame'.")

      if( any(colnames(pobj) %in% colnames(sampleInfo(gobj))) )
         sampleInfo(gobj) <- merge(sampleInfo(gobj), pobj, all.x=TRUE)
      else
         sampleInfo(gobj) <- cbind(sampleInfo(gobj), pobj)
    }

  ## (optional) step 3: load the marker data
  if(!missing(mfile) && !is.null(mfile))
    {
      moptions$file <- mfile
      mobj <- do.call(mformat, moptions)
      if(!("data.frame" %in% class(mobj)))
        stop("Call to function ", mformat,
             " failed to return an object of class `data.frame'.")

      if( is.null(markerInfo(gobj)) )
         markerInfo(gobj) <- mobj
      else if( any(colnames(mobj) %in% colnames(markerInfo(gobj))) )
         markerInfo(gobj) <- merge(markerInfo(gobj), mobj, all.x=TRUE)
      else if(nrow(markerInfo(gobj))==nrow(mobj))
         markerInfo(gobj) <- cbind(markerInfo(gobj), mobj)
      else
        warning("Marker file info does not match dimensions or marker names from genotype file. Ignoring")
    }
  

  gobj
}
